@@ -39,6 +39,17 @@ set keymap {
 #----------------------------------------------------------------
 # create virtual keyboard
 
+proc CheckKeymap {target} {
+    global keymap keywin
+    foreach i $keymap {
+	set key [lindex $i 0]
+        if {$key == $target} {
+	    return 0
+	}
+    }
+    return 1
+}
+
 proc KeybdCreate {w} {
     global keycolor keywid keyitem keyindex keyhgt keymap keywin
     global optvar
@@ -87,9 +98,13 @@ proc KeybdCreate {w} {
     #
     # some special key sequences
     #
-    bind $w <Key-Escape> {SeqOff; ResetControls}
+    if [CheckKeymap Escape] {
+	bind $w <Key-Escape> {SeqOff; ResetControls}
+    }
+    if [CheckKeymap q] {
+	bind $w <Key-q> {exit 0}
+    }
     bind $w <Control-c> {exit 0}
-    bind $w <Key-q> {exit 0}
     focus $w
 }
 
@@ -633,12 +648,24 @@ proc ParseOptions {argc argv} {
 	set arg [lindex $argv $i]
 	if {! [string match -* $arg]} {break}
 	set arg [string range $arg 2 end]
-	if {[info exists optvar($arg)]} {
-	    incr i
-	    set optvar($arg) [lindex $argv $i]
+	if {[string match *=* $arg]} {
+	    set idx [string first = $arg]
+	    set val [string range $arg [expr $idx + 1] end]
+	    set arg [string range $arg 0 [expr $idx - 1]]
+	    if {[info exists optvar($arg)]} {
+		set optvar($arg) $val
+	    } else {
+		usage
+		exit 1
+	    }
 	} else {
-	    usage
-	    exit 1
+	    if {[info exists optvar($arg)]} {
+		incr i
+		set optvar($arg) [lindex $argv $i]
+	    } else {
+		usage
+		exit 1
+	    }
 	}
     }
 }
